@@ -1,4 +1,4 @@
 #!/bin/bash
 
 # Kicks off dhcpd startup in the background so udev can go about its work.
-$(dirname $0)/start_concordance_dhcpd.sh >/dev/null 2>&1 &
+echo $(dirname $0)/start_concordance_dhcpd.sh | at now
